==================
Guide (core)
==================
This section contains the guide to using the Discord Advertisement Framework at it's core (console) or in other
words, running it directly by Python and providing all the required information inside a Python script (``.py`` file).


.. toctree::

    control
    shilldefine
    logging
    logic
    autogen
    autoresponder
    web
    modification
    remote
